@@ -3,9 +3,11 @@ function(
 formula,
 data,
 family = gaussian,
-method = "lqa", 
-tuning = list(lambda=TRUE, phi=0.5),
+method = c("lqa", "AIC", "BIC"),
+tuning = list(lambda=TRUE, specific=FALSE, phi=0.5, grouped.fused=0.5, elastic=0.5, vs=0.5, spl=0.5),
 weights,
+offset,
+start,
 control,
 model = FALSE,
 x = FALSE,
